//+------------------------------------------------------------------+
//|                                     Average profit close all.mq5 |
//|                                     Dawid & Saherlene Zinserling |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Dawid & Saherlene Zinserling"
#property link      "https://www.mql5.com"
#property strict

#include <Trade/Trade.mqh>

input int                InputMaxTrades            = 10;                 // Max number of trades
input double             InpTradeGap               = 0.005;              // Minimum gap between trades
input ENUM_ORDER_TYPE    InpType                   = ORDER_TYPE_BUY;     // Order type;
input double             InpMinProfit              = 1.00;               // Profit in bas currency
input int                InpMagicNumber            = 19790927;           // Magic number
input string             InpTradeComment           = __FILE__;           // Trade comment
input double             InputVolume               = 0.01;               // Volume per order

struct StradeSum {
     int     count;
     double  profit;
     double  trailPrice;
}; 

CTrade   Trade;
 
int OnInit() {

     Trade.SetExpertMagicNumber(InpMagicNumber);
   
   return(INIT_SUCCEEDED);
  }

void OnDeinit(const int reason)  {


  }

void OnTick(){

    StradeSum sum;
    GetSum(sum);
    
    if (sum.profit>InpMinProfit) { // target reached
        CloseAll();
    } else
    if (sum.count==0)  {  // no trades
       OpenTrade();
    } else
    if (sum.count<InputMaxTrades) {
       if ( InpType==ORDER_TYPE_BUY
            && SymbolInfoDouble(Symbol(),SYMBOL_ASK)<=(sum.trailPrice-InpTradeGap)           
            ) {  // Far enough below
          OpenTrade();
            } else
         if ( InpType==ORDER_TYPE_SELL
            && SymbolInfoDouble(Symbol(), SYMBOL_BID)>=(sum.trailPrice+InpTradeGap)
            ) {  // Far enough above
          OpenTrade();
      }
    } 
     
  }
  
void OpenTrade() {

     double  price = (InpType==ORDER_TYPE_BUY) ?
                       SymbolInfoDouble(Symbol(),SYMBOL_ASK) :
                       SymbolInfoDouble(Symbol(),SYMBOL_BID);
     Trade.PositionOpen(Symbol(), InpType, InputVolume, price, 0, 0, InpTradeComment);
     
}

void CloseAll() {

     int count   = PositionsTotal();
     
     for (int i = count-1; i>=0; i--)  {
       ulong ticket = PositionGetTicket(i);
       if (ticket>0) {
         if ( PositionGetString(POSITION_SYMBOL)==Symbol()
              && PositionGetInteger(POSITION_MAGIC)==InpMagicNumber
              && PositionGetInteger(POSITION_TYPE)==InpType       
              ) {
         Trade.PositionClose(ticket);
         }
       }  
     }

   }
   
void  GetSum(StradeSum &sum) {

   int   count   = PositionsTotal();
   
   sum.count      = 0;
   sum.profit     = 0.0;
   sum.trailPrice = 0.0;
   
   for (int i = count-1; i>=0; i--)  {
       ulong ticket  = PositionGetTicket(i);
       if (ticket>0) {
           if (PositionGetString(POSITION_SYMBOL)==Symbol()
           && PositionGetInteger(POSITION_MAGIC)==InpMagicNumber
           && PositionGetInteger(POSITION_TYPE)==InpType) {
         sum.count++;
         sum.profit  += PositionGetDouble(POSITION_PROFIT)+PositionGetDouble(POSITION_SWAP);
         if (InpType==ORDER_TYPE_BUY) {
            if (sum.trailPrice==0   ||  PositionGetDouble(POSITION_PRICE_OPEN)<sum.trailPrice) {
               sum.trailPrice = PositionGetDouble(POSITION_PRICE_OPEN);
              }         
           } else
           if (InpType==ORDER_TYPE_SELL) {
             if (sum.trailPrice==0  ||  PositionGetDouble(POSITION_PRICE_OPEN)<sum.trailPrice) {
                sum.trailPrice = PositionGetDouble(POSITION_PRICE_OPEN);
             }
             }
           
           }
       }
   
   }

return;

}
//+------------------------------------------------------------------+
